# Jira Integration
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/jira-integration#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/jira-integration#benefits)
  * [Scope and Limitations](https://help.sap.com/docs/leanix/ea/jira-integration#scope-and-limitations)
  * [Setting Up the Integration](https://help.sap.com/docs/leanix/ea/jira-integration#setting-up-the-integration)
  * [API Endpoints Used by the Integration](https://help.sap.com/docs/leanix/ea/jira-integration#api-endpoints-used-by-the-integration)
  * [Syncing Data Between Jira and SAP LeanIX](https://help.sap.com/docs/leanix/ea/jira-integration#syncing-data-between-jira-and-sap-leanix)
  * [Tracking Progress on Linked Jira Work Items](https://help.sap.com/docs/leanix/ea/jira-integration#tracking-progress-on-linked-jira-work-items)
  * [Syncing Jira Data Manually](https://help.sap.com/docs/leanix/ea/jira-integration#syncing-jira-data-manually)


Sync epics, to-dos, and issues from multiple Jira projects and instances to SAP LeanIX initiatives, and define how you track progress.
**Note**
The Jira integration with project-level synchronization is available exclusively through [SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD "The SAP LeanIX Architecture and Road Map Planning enhances SAP LeanIX Application Portfolio Management by offering advanced features for seamless planning and execution of transformation initiatives in enterprise architecture management.").
If you don’t have access to SAP LeanIX Architecture and Road Map Planning, you can use the lightweight SAP LeanIX for Jira app on the Atlassian Marketplace. Keep in mind that this version is intended for basic use cases only and does not support project-level synchronization. For more details, visit [Jira Marketplace App](https://help.sap.com/docs/leanix/ea/jira-software-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Sync your Jira issues with your architecture data to enhance productivity and gain insight into ongoing enterprise architecture initiatives.").
